@@ -18,6 +18,7 @@ import http.client as http
 import os
 import re
 import urllib.parse as urlparse
+import uuid
 
 from castellan.common import exception as castellan_exception
 from castellan import key_manager
@@ -90,10 +91,8 @@ class ImagesController(object):
 
     @utils.mutating
     def create(self, req, image, extra_properties, tags):
-        image_factory = self.gateway.get_image_factory(
-            req.context, authorization_layer=False)
-        image_repo = self.gateway.get_repo(req.context,
-                                           authorization_layer=False)
+        image_factory = self.gateway.get_image_factory(req.context)
+        image_repo = self.gateway.get_repo(req.context)
         try:
             if 'owner' not in image:
                 image['owner'] = req.context.project_id
@@ -166,10 +165,8 @@ class ImagesController(object):
 
     def _enforce_import_lock(self, req, image):
         admin_context = req.context.elevated()
-        admin_image_repo = self.gateway.get_repo(
-            admin_context, authorization_layer=False)
-        admin_task_repo = self.gateway.get_task_repo(
-            admin_context, authorization_layer=False)
+        admin_image_repo = self.gateway.get_repo(admin_context)
+        admin_task_repo = self.gateway.get_task_repo(admin_context)
         other_task = image.extra_properties['os_glance_import_task']
 
         expiry = datetime.timedelta(minutes=60)
@@ -281,7 +278,7 @@ class ImagesController(object):
             raise webob.exc.HTTPBadGateway('Stage host is unavailable')
         req_id_hdr = 'x-openstack-request-id'
         if req_id_hdr in r.headers:
-            LOG.debug('Replying with remote request id %s' % (
+            LOG.debug('Replying with remote request id %s', (
                 r.headers[req_id_hdr]))
             req.context.request_id = r.headers[req_id_hdr]
         if r.status_code // 100 != 2:
@@ -313,12 +310,9 @@ class ImagesController(object):
     @utils.mutating
     def import_image(self, req, image_id, body):
         ctxt = req.context
-        image_repo = self.gateway.get_repo(ctxt,
-                                           authorization_layer=False)
-        task_factory = self.gateway.get_task_factory(
-            ctxt, authorization_layer=False)
-        task_repo = self.gateway.get_task_repo(
-            ctxt, authorization_layer=False)
+        image_repo = self.gateway.get_repo(ctxt)
+        task_factory = self.gateway.get_task_factory(ctxt)
+        task_repo = self.gateway.get_task_repo(ctxt)
         import_method = body.get('method').get('name')
         uri = body.get('method').get('uri')
         all_stores_must_succeed = body.get('all_stores_must_succeed', True)
@@ -339,9 +333,10 @@ class ImagesController(object):
                 msg = _("Only images with status active can be targeted for "
                         "copying")
                 raise exception.Conflict(msg)
-            if image.status != 'queued' and import_method == 'web-download':
+            if (image.status != 'queued' and
+                    import_method in ['web-download', 'glance-download']):
                 msg = _("Image needs to be in 'queued' state to use "
-                        "'web-download' method")
+                        "'%s' method") % import_method
                 raise exception.Conflict(msg)
             if (image.status != 'uploading' and
                     import_method == 'glance-direct'):
@@ -354,6 +349,23 @@ class ImagesController(object):
             if not getattr(image, 'disk_format', None):
                 msg = _("'disk_format' needs to be set before import")
                 raise exception.Conflict(msg)
+            if import_method == 'glance-download':
+                if 'glance_region' not in body.get('method'):
+                    msg = _("'glance_region' needs to be set for "
+                            "glance-download import method")
+                    raise webob.exc.HTTPBadRequest(explanation=msg)
+                if 'glance_image_id' not in body.get('method'):
+                    msg = _("'glance_image_id' needs to be set for "
+                            "glance-download import method")
+                    raise webob.exc.HTTPBadRequest(explanation=msg)
+                try:
+                    uuid.UUID(body['method']['glance_image_id'])
+                except ValueError:
+                    msg = (_("Remote image id does not look like a UUID: %s")
+                           % body['method']['glance_image_id'])
+                    raise webob.exc.HTTPBadRequest(explanation=msg)
+                if 'glance_service_interface' not in body.get('method'):
+                    body.get('method')['glance_service_interface'] = 'public'
 
             # NOTE(danms): For copy-image only, we check policy to decide
             # if the user should be able to do this. Otherwise, we forbid
@@ -391,7 +403,7 @@ class ImagesController(object):
                     if existing_store in stores:
                         LOG.debug("Removing store '%s' from all stores as "
                                   "image is already available in that "
-                                  "store." % existing_store)
+                                  "store.", existing_store)
                         stores.remove(existing_store)
 
                 if len(stores) == 0:
@@ -439,7 +451,7 @@ class ImagesController(object):
             admin_context = None
 
         executor_factory = self.gateway.get_task_executor_factory(
-            ctxt, admin_context=admin_context, authorization_layer=False)
+            ctxt, admin_context=admin_context)
 
         if (import_method == 'web-download' and
                 not utils.validate_import_uri(uri)):
@@ -528,8 +540,7 @@ class ImagesController(object):
             limit = CONF.limit_param_default
         limit = min(CONF.api_limit_max, limit)
 
-        image_repo = self.gateway.get_repo(req.context,
-                                           authorization_layer=False)
+        image_repo = self.gateway.get_repo(req.context)
         try:
             # NOTE(danms): This is just a "do you have permission to
             # list images" check. Each image is checked against
@@ -568,8 +579,7 @@ class ImagesController(object):
         return result
 
     def show(self, req, image_id):
-        image_repo = self.gateway.get_repo(req.context,
-                                           authorization_layer=False)
+        image_repo = self.gateway.get_repo(req.context)
         try:
             image = image_repo.get(image_id)
             api_policy.ImageAPIPolicy(req.context, image,
@@ -581,8 +591,7 @@ class ImagesController(object):
             raise webob.exc.HTTPUnauthorized(explanation=e.msg)
 
     def get_task_info(self, req, image_id):
-        image_repo = self.gateway.get_repo(
-            req.context, authorization_layer=False)
+        image_repo = self.gateway.get_repo(req.context)
 
         try:
             # NOTE (abhishekk): Just to check image is valid
@@ -600,8 +609,7 @@ class ImagesController(object):
 
     @utils.mutating
     def update(self, req, image_id, changes):
-        image_repo = self.gateway.get_repo(req.context,
-                                           authorization_layer=False)
+        image_repo = self.gateway.get_repo(req.context)
         try:
             image = image_repo.get(image_id)
             api_pol = api_policy.ImageAPIPolicy(req.context, image,
@@ -734,8 +742,7 @@ class ImagesController(object):
                    store_id)
             raise webob.exc.HTTPConflict(explanation=msg)
 
-        image_repo = self.gateway.get_repo(
-            req.context, authorization_layer=False)
+        image_repo = self.gateway.get_repo(req.context)
         try:
             image = image_repo.get(image_id)
         except exception.NotAuthenticated as e:
@@ -837,14 +844,11 @@ class ImagesController(object):
             # continue on the local worker to match the user's
             # expectations. If the image is already deleted, the caller
             # will catch this NotFound like normal.
-            return self.gateway.get_repo(
-                req.context,
-                authorization_layer=False).get(image.image_id)
+            return self.gateway.get_repo(req.context).get(image.image_id)
 
     @utils.mutating
     def delete(self, req, image_id):
-        image_repo = self.gateway.get_repo(req.context,
-                                           authorization_layer=False)
+        image_repo = self.gateway.get_repo(req.context)
         try:
             image = image_repo.get(image_id)
 
