@@ -9,13 +9,14 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
+
+import io
 import sys
 from unittest import mock
 
 import glance_store as store
 from oslo_config import cfg
 from oslo_log import log as logging
-import six
 
 import glance.cmd.api
 import glance.cmd.cache_cleaner
@@ -48,7 +49,7 @@ class TestGlanceApiCmd(test_utils.BaseTestCase):
         super(TestGlanceApiCmd, self).setUp()
         self.__argv_backup = sys.argv
         sys.argv = ['glance-api']
-        self.stderr = six.StringIO()
+        self.stderr = io.StringIO()
         sys.stderr = self.stderr
 
         store.register_opts(CONF)
@@ -65,12 +66,16 @@ class TestGlanceApiCmd(test_utils.BaseTestCase):
         sys.argv = self.__argv_backup
         super(TestGlanceApiCmd, self).tearDown()
 
+    @mock.patch('glance.async_.set_threadpool_model',)
     @mock.patch.object(prefetcher, 'Prefetcher')
-    def test_supported_default_store(self, mock_prefetcher):
+    def test_supported_default_store(self, mock_prefetcher, mock_set_model):
         self.config(group='glance_store', default_store='file')
         glance.cmd.api.main()
+        # Make sure we declared the system threadpool model as eventlet
+        mock_set_model.assert_called_once_with('eventlet')
 
     @mock.patch.object(prefetcher, 'Prefetcher')
+    @mock.patch('glance.async_.set_threadpool_model', new=mock.MagicMock())
     def test_worker_creation_failure(self, mock_prefetcher):
         failure = exc.WorkerCreationFailure(reason='test')
         self.mock_object(glance.common.wsgi.Server, 'start',
@@ -157,7 +162,7 @@ class TestGlanceApiCmd(test_utils.BaseTestCase):
     def test_fail_with_unknown_exception(self):
         with mock.patch('sys.stderr.write') as mock_stderr:
             with mock.patch('sys.exit') as mock_exit:
-                exc_msg = 'A Crazy Unkown Error.'
+                exc_msg = 'A Crazy Unknown Error.'
                 exc = CrayCray(exc_msg)
                 glance.cmd.api.fail(exc)
                 mock_stderr.assert_called_once_with('ERROR: %s\n' % exc_msg)
